@@ -1,22 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "archivemailagent.h"
 #include "archivemailagentadaptor.h"
-#include "archivemailmanager.h"
 #include "archivemailagentsettings.h"
+#include "archivemailmanager.h"
 #include <AkonadiCore/ServerManager>
 
-#include <MailCommon/MailKernel>
-#include <QDBusConnection>
-#include <Monitor>
-#include <Session>
 #include <CollectionFetchScope>
 #include <KMime/Message>
+#include <MailCommon/MailKernel>
+#include <Monitor>
+#include <QDBusConnection>
 #include <QTimer>
+#include <Session>
 
 #include <Kdelibs4ConfigMigrator>
 
@@ -34,7 +34,7 @@ ArchiveMailAgent::ArchiveMailAgent(const QString &id)
 
     connect(mArchiveManager, &ArchiveMailManager::needUpdateConfigDialogBox, this, &ArchiveMailAgent::needUpdateConfigDialogBox);
 
-    auto *collectionMonitor = new Akonadi::Monitor(this);
+    auto collectionMonitor = new Akonadi::Monitor(this);
     collectionMonitor->setObjectName(QStringLiteral("ArchiveMailCollectionMonitor"));
     collectionMonitor->fetchCollection(true);
     collectionMonitor->ignoreSession(Akonadi::Session::defaultSession());
@@ -62,8 +62,7 @@ ArchiveMailAgent::ArchiveMailAgent(const QString &id)
     mTimer->start(24 * 60 * 60 * 1000);
 }
 
-ArchiveMailAgent::~ArchiveMailAgent()
-= default;
+ArchiveMailAgent::~ArchiveMailAgent() = default;
 
 void ArchiveMailAgent::setEnableAgent(bool enabled)
 {
