@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,9 @@
 #include "archivemailwidgettest.h"
 #include "../archivemailwidget.h"
 
+#include <QStandardPaths>
 #include <QTest>
 #include <QTreeWidget>
-#include <QStandardPaths>
 
 ArchiveMailWidgetTest::ArchiveMailWidgetTest(QObject *parent)
     : QObject(parent)
@@ -17,8 +17,7 @@ ArchiveMailWidgetTest::ArchiveMailWidgetTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-ArchiveMailWidgetTest::~ArchiveMailWidgetTest()
-= default;
+ArchiveMailWidgetTest::~ArchiveMailWidgetTest() = default;
 
 void ArchiveMailWidgetTest::shouldHaveDefaultValue()
 {
@@ -26,7 +25,7 @@ void ArchiveMailWidgetTest::shouldHaveDefaultValue()
     new QHBoxLayout(&parent);
     ArchiveMailWidget mailwidget({}, &parent, {QStringLiteral("akonadi_archivemail_agent")});
 
-    auto *treeWidget = parent.findChild<QTreeWidget *>(QStringLiteral("treewidget"));
+    auto treeWidget = parent.findChild<QTreeWidget *>(QStringLiteral("treewidget"));
     QVERIFY(treeWidget);
 
     QCOMPARE(treeWidget->topLevelItemCount(), 0);
