@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "followupreminderinfoconfigwidget.h"
 #include "followupreminderinfowidget.h"
 #include "kmail-version.h"
-#include <QLayout>
 #include <KAboutData>
 #include <KLocalizedString>
 #include <KSharedConfig>
-namespace {
+#include <QLayout>
+namespace
+{
 static const char myConfigGroupName[] = "FollowUpReminderInfoDialog";
 }
 
@@ -20,25 +21,21 @@ FollowUpReminderInfoConfigWidget::FollowUpReminderInfoConfigWidget(const KShared
     mWidget = new FollowUpReminderInfoWidget(parent);
     parent->layout()->addWidget(mWidget);
 
-    KAboutData aboutData = KAboutData(
-        QStringLiteral("followupreminderagent"),
-        i18n("Follow Up Reminder Agent"),
-        QStringLiteral(KDEPIM_VERSION),
-        i18n("Follow Up Reminder"),
-        KAboutLicense::GPL_V2,
-        i18n("Copyright (C) 2014-2020 Laurent Montel"));
+    KAboutData aboutData = KAboutData(QStringLiteral("followupreminderagent"),
+                                      i18n("Follow Up Reminder Agent"),
+                                      QStringLiteral(KDEPIM_VERSION),
+                                      i18n("Follow Up Reminder"),
+                                      KAboutLicense::GPL_V2,
+                                      i18n("Copyright (C) 2014-2020 Laurent Montel"));
 
-    aboutData.addAuthor(i18n("Laurent Montel"),
-                        i18n("Maintainer"), QStringLiteral("montel@kde.org"));
+    aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
-    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"),
-                            i18nc("EMAIL OF TRANSLATORS", "Your emails"));
+    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
     setKAboutData(aboutData);
 }
 
-FollowUpReminderInfoConfigWidget::~FollowUpReminderInfoConfigWidget()
-= default;
+FollowUpReminderInfoConfigWidget::~FollowUpReminderInfoConfigWidget() = default;
 
 void FollowUpReminderInfoConfigWidget::load()
 {
