@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,11 +9,13 @@
 
 #include <KSharedConfig>
 
-namespace FollowUpReminder {
+namespace FollowUpReminder
+{
 class FollowUpReminderInfo;
 
 /** Follow up reminder utilities. */
-namespace FollowUpReminderUtil {
+namespace FollowUpReminderUtil
+{
 Q_REQUIRED_RESULT bool followupReminderAgentWasRegistered();
 
 Q_REQUIRED_RESULT bool followupReminderAgentEnabled();
