@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "followupremindershowmessagejob.h"
 #include "followupreminderagent_debug.h"
-#include <QDBusConnection>
-#include <QDBusInterface>
-#include <QDBusConnectionInterface>
 #include <KToolInvocation>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QDBusInterface>
 
 FollowUpReminderShowMessageJob::FollowUpReminderShowMessageJob(Akonadi::Item::Id id, QObject *parent)
     : QObject(parent)
@@ -17,8 +17,7 @@ FollowUpReminderShowMessageJob::FollowUpReminderShowMessageJob(Akonadi::Item::Id
 {
 }
 
-FollowUpReminderShowMessageJob::~FollowUpReminderShowMessageJob()
-= default;
+FollowUpReminderShowMessageJob::~FollowUpReminderShowMessageJob() = default;
 
 void FollowUpReminderShowMessageJob::start()
 {
