@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class FollowUpReminderShowMessageJob : public QObject
     Q_OBJECT
 public:
     explicit FollowUpReminderShowMessageJob(Akonadi::Item::Id id, QObject *parent = nullptr);
-    ~FollowUpReminderShowMessageJob();
+    ~FollowUpReminderShowMessageJob() override;
 
     void start();
 
