@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sendlaterremovemessagejob.h"
-#include <ItemDeleteJob>
 #include "sendlateragent_debug.h"
+#include <ItemDeleteJob>
 
 SendLaterRemoveMessageJob::SendLaterRemoveMessageJob(const QVector<Akonadi::Item::Id> &listItem, QObject *parent)
     : QObject(parent)
@@ -14,8 +14,7 @@ SendLaterRemoveMessageJob::SendLaterRemoveMessageJob(const QVector<Akonadi::Item
 {
 }
 
-SendLaterRemoveMessageJob::~SendLaterRemoveMessageJob()
-= default;
+SendLaterRemoveMessageJob::~SendLaterRemoveMessageJob() = default;
 
 void SendLaterRemoveMessageJob::start()
 {
@@ -25,7 +24,7 @@ void SendLaterRemoveMessageJob::start()
 void SendLaterRemoveMessageJob::deleteItem()
 {
     if (mIndex < mListItems.count()) {
-        Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob(Akonadi::Item(mListItems.at(mIndex)), this);
+        auto job = new Akonadi::ItemDeleteJob(Akonadi::Item(mListItems.at(mIndex)), this);
         connect(job, &Akonadi::ItemDeleteJob::result, this, &SendLaterRemoveMessageJob::slotItemDeleteDone);
     } else {
         deleteLater();
