@@ -21,7 +21,8 @@
 #include <QMap>
 #include <QPixmap>
 
-namespace KTnef {
+namespace KTnef
+{
 class KTNEFAttach;
 class KTNEFProperty;
 class KTNEFPropertySet;
@@ -36,7 +37,7 @@ class AttachPropertyDialog : public QDialog
     Q_OBJECT
 public:
     explicit AttachPropertyDialog(QWidget *parent = nullptr);
-    ~AttachPropertyDialog();
+    ~AttachPropertyDialog() override;
 
     void setAttachment(KTNEFAttach *attach);
 
