@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,8 +12,7 @@ CreateFollowupReminderOnExistingMessageJobTest::CreateFollowupReminderOnExisting
 {
 }
 
-CreateFollowupReminderOnExistingMessageJobTest::~CreateFollowupReminderOnExistingMessageJobTest()
-= default;
+CreateFollowupReminderOnExistingMessageJobTest::~CreateFollowupReminderOnExistingMessageJobTest() = default;
 
 void CreateFollowupReminderOnExistingMessageJobTest::shouldHaveDefaultValue()
 {
