@@ -1,15 +1,15 @@
 /*
  *
  * SPDX-FileCopyrightText: 2006 Till Adam <adam@kde.org>
- * SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #include "collectionquotapage.h"
 #include "collectionquotawidget.h"
-#include <AkonadiCore/collectionquotaattribute.h>
 #include <AkonadiCore/collection.h>
+#include <AkonadiCore/collectionquotaattribute.h>
 
 #include <KLocalizedString>
 #include <QVBoxLayout>
@@ -34,7 +34,7 @@ bool CollectionQuotaPage::canHandle(const Akonadi::Collection &collection) const
 
 void CollectionQuotaPage::init()
 {
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
     mQuotaWidget = new CollectionQuotaWidget(this);
     topLayout->addWidget(mQuotaWidget);
 }
@@ -45,7 +45,7 @@ void CollectionQuotaPage::load(const Akonadi::Collection &col)
         const qint64 currentValue = col.attribute<Akonadi::CollectionQuotaAttribute>()->currentValue();
 
         const qint64 maximumValue = col.attribute<Akonadi::CollectionQuotaAttribute>()->maximumValue();
-        //Test over quota.
+        // Test over quota.
         mQuotaWidget->setQuotaInfo(qMin(currentValue, maximumValue), maximumValue);
     }
 }
