@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef COLLECTIONVIEWPAGE_H
 #define COLLECTIONVIEWPAGE_H
 
-#include <AkonadiWidgets/collectionpropertiespage.h>
 #include <AkonadiCore/collection.h>
+#include <AkonadiWidgets/collectionpropertiespage.h>
 #include <MailCommon/FolderSettings>
 class QCheckBox;
 class QLabel;
@@ -16,7 +16,8 @@ class KIconButton;
 class CollectionViewWidget;
 template<typename T> class QSharedPointer;
 
-namespace MailCommon {
+namespace MailCommon
+{
 class CollectionViewWidget;
 }
 class CollectionViewPage : public Akonadi::CollectionPropertiesPage
