@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,17 +7,18 @@
 #ifndef CONFIGURESECURITYPAGE_H
 #define CONFIGURESECURITYPAGE_H
 
-#include "kmail_export.h"
 #include "configuredialog_p.h"
+#include "kmail_export.h"
+#include "ui_composercryptoconfiguration.h"
 #include "ui_securitypagegeneraltab.h"
 #include "ui_securitypagemdntab.h"
-#include "ui_composercryptoconfiguration.h"
-#include "ui_warningconfiguration.h"
 #include "ui_smimeconfiguration.h"
+#include "ui_warningconfiguration.h"
 
 #include <KCMultiDialog>
 
-namespace QGpgME {
+namespace QGpgME
+{
 class CryptoConfig;
 }
 
@@ -34,6 +35,7 @@ private:
     void doLoadOther() override;
 
 private:
+    void slotOpenExternalReferenceExceptions();
     void slotLinkClicked(const QString &link);
     Ui_SecurityPageGeneralTab mSGTab;
 };
@@ -125,6 +127,7 @@ class GpgSettingsDialog : public KCMultiDialog
 public:
     explicit GpgSettingsDialog(QWidget *parent = nullptr);
     ~GpgSettingsDialog();
+
 private:
     void readConfig();
     void saveConfig();
