@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <QObject>
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class PluginEditorCheckBeforeSendInterface;
 class PluginEditorCheckBeforeSendParams;
 }
@@ -19,17 +20,18 @@ class KMailPluginEditorCheckBeforeSendManagerInterface : public QObject
     Q_OBJECT
 public:
     explicit KMailPluginEditorCheckBeforeSendManagerInterface(QObject *parent = nullptr);
-    ~KMailPluginEditorCheckBeforeSendManagerInterface();
+    ~KMailPluginEditorCheckBeforeSendManagerInterface() override;
 
     QWidget *parentWidget() const;
     void setParentWidget(QWidget *parentWidget);
 
-    //TODO add Identity
-    //TODO add Emails
-    //TODO add body ? or editor
+    // TODO add Identity
+    // TODO add Emails
+    // TODO add body ? or editor
 
     void initializePlugins();
     bool execute(const MessageComposer::PluginEditorCheckBeforeSendParams &params) const;
+
 private:
     Q_DISABLE_COPY(KMailPluginEditorCheckBeforeSendManagerInterface)
     QList<MessageComposer::PluginEditorCheckBeforeSendInterface *> mListPluginInterface;
