@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,19 +8,20 @@
 #ifndef POTENTIALPHISHINGDETAILWIDGET_H
 #define POTENTIALPHISHINGDETAILWIDGET_H
 
-#include <QWidget>
 #include "kmail_private_export.h"
+#include <QWidget>
 class QListWidget;
 class KMAILTESTS_TESTS_EXPORT PotentialPhishingDetailWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit PotentialPhishingDetailWidget(QWidget *parent = nullptr);
-    ~PotentialPhishingDetailWidget();
+    ~PotentialPhishingDetailWidget() override;
 
     void save();
 
     void fillList(const QStringList &lst);
+
 private:
     QListWidget *const mListWidget = nullptr;
 };
