@@ -18,22 +18,19 @@ class QComboBox;
 class QLineEdit;
 class QButtonGroup;
 
-namespace KIdentityManagement {
+namespace KIdentityManagement
+{
 class IdentityManager;
 }
 
-namespace KMail {
+namespace KMail
+{
 class NewIdentityDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-
-    enum DuplicateMode {
-        Empty = 0,
-        ControlCenter,
-        ExistingEntry
-    };
+    enum DuplicateMode { Empty = 0, ControlCenter, ExistingEntry };
     explicit NewIdentityDialog(KIdentityManagement::IdentityManager *manager, QWidget *parent = nullptr);
 
     Q_REQUIRED_RESULT QString identityName() const;
