@@ -4,10 +4,10 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <KSieveUi/ManageSieveScriptsDialog>
-#include <KSieveUi/SieveImapInstanceInterfaceManager>
 #include "../../../sieveimapinterface/kmailsieveimapinstanceinterface.h"
 #include "../../../sieveimapinterface/kmsieveimappasswordprovider.h"
+#include <KSieveUi/ManageSieveScriptsDialog>
+#include <KSieveUi/SieveImapInstanceInterfaceManager>
 #include <QApplication>
 
 int main(int argc, char **argv)
@@ -17,8 +17,8 @@ int main(int argc, char **argv)
     QApplication::setApplicationVersion(QStringLiteral("1.0"));
 
     KSieveUi::SieveImapInstanceInterfaceManager::self()->setSieveImapInstanceInterface(new KMailSieveImapInstanceInterface);
-    KMSieveImapPasswordProvider provider(0);
-    auto *dlg = new KSieveUi::ManageSieveScriptsDialog(&provider);
+    KMSieveImapPasswordProvider provider(nullptr);
+    auto dlg = new KSieveUi::ManageSieveScriptsDialog(&provider);
     dlg->show();
     return app.exec();
 }
