@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -7,10 +7,11 @@
 #ifndef TAGMONITORMANAGER_H
 #define TAGMONITORMANAGER_H
 
-#include <QObject>
 #include <AkonadiCore/Tag>
+#include <QObject>
 #include <mailcommon/tag.h>
-namespace Akonadi {
+namespace Akonadi
+{
 class Monitor;
 }
 class KJob;
@@ -20,7 +21,7 @@ class TagMonitorManager : public QObject
     Q_OBJECT
 public:
     explicit TagMonitorManager(QObject *parent = nullptr);
-    ~TagMonitorManager();
+    ~TagMonitorManager() override;
 
     static TagMonitorManager *self();
 
