@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class CollectionPane : public MessageList::Pane
     Q_OBJECT
 public:
     explicit CollectionPane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent = nullptr);
-    ~CollectionPane();
+    ~CollectionPane() override;
 
     MessageList::StorageModel *createStorageModel(QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent) override;
     void writeConfig(bool restoreSession) override;
@@ -26,10 +26,10 @@ class CollectionStorageModel : public MessageList::StorageModel
     Q_OBJECT
 public:
     /**
-    * Create a StorageModel wrapping the specified folder.
-    */
+     * Create a StorageModel wrapping the specified folder.
+     */
     explicit CollectionStorageModel(QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent = nullptr);
-    ~CollectionStorageModel();
+    ~CollectionStorageModel() override;
     Q_REQUIRED_RESULT bool isOutBoundFolder(const Akonadi::Collection &c) const override;
 };
 
