@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class ZoomLabelWidget : public QLabel
     Q_OBJECT
 public:
     explicit ZoomLabelWidget(QWidget *parent = nullptr);
-    ~ZoomLabelWidget();
+    ~ZoomLabelWidget() override;
 
     void setZoom(qreal zoomFactor);
 };
